KaeruWidgetClipExtension extension

Quick clipping methods on any widget.

on

Properties

circle Widget

Available on Widget, provided by the KaeruWidgetClipExtension extension

Clips the widget into a circle.
no setter

Methods

clip({CustomClipper<Rect>? clipper, Clip clipBehavior = Clip.hardEdge}) Widget

Available on Widget, provided by the KaeruWidgetClipExtension extension

Wraps the widget in a ClipRect.
height(double height) Widget

Available on Widget, provided by the KaeruWidgetClipExtension extension

Constrains the widget to the given height.
rounded([double radius = 8]) Widget

Available on Widget, provided by the KaeruWidgetClipExtension extension

Clips the widget with rounded corners.
size(double width, double height) Widget

Available on Widget, provided by the KaeruWidgetClipExtension extension

Constrains the widget to the given width and height.
square(double size) Widget

Available on Widget, provided by the KaeruWidgetClipExtension extension

Constrains the widget to a square of the given size.
width(double width) Widget

Available on Widget, provided by the KaeruWidgetClipExtension extension

Constrains the widget to the given width.