mar method
Wraps the widget in a container with the specified p margin.
Implementation
Widget mar(EdgeInsetsGeometry p) => box.mar(p).make();
Wraps the widget in a container with the specified p margin.
Widget mar(EdgeInsetsGeometry p) => box.mar(p).make();